# 行业
data = ['3C及电器', '消费类电子产品', '摄影', '摄像设备', '随身影音', '办公设备', '智能穿戴设备',
        '其他消费类电子产品', '网络设备', '电子教育设备',
        '游戏设备', '数码存储设备', '其他3C及电器', '手机', '电脑', '3C及电器电商', '3C及电器线下零售',
        '小家电', '厨卫小家电', '个护健康家电',
        '其他小家电', '生活小家电', '家电配件', '大家电', '商用电器', '其他大家电', '3C数码配件',
        '食品饮料', '烟', '烟酒电商', '烟酒线下零售',
        '休闲零食', '坚果炒货', '糖果巧克力', '饼干膨化', '健康代餐零食', '肉干肉脯', '熏腊卤味',
        '肉类熟食', '其他休闲零食', '饮料冲调', '其他饮料冲调',
        '果汁饮料', '包装水', '成人奶粉', '咖啡', '藕粉', '麦片', '冲饮品', '碳酸饮料', '功能饮料',
        '食补粉', '天然粉', '代餐粉、奶昔',
        '乳制品及乳制品饮料', '乳制品', '奶酪', '奶制品', '冰激凌', '其他乳制品及乳制品饮料', '粮油米面',
        '调味品', '其他粮油米面', '方便速食', '食用油',
        '生鲜', '肉禽蛋', '海产', '蔬菜', '水果', '其他生鲜', '冷藏', '冷冻食品', '其他食用初级农产品',
        '其他食品饮料', '酒', '白酒', '黄酒',
        '葡萄酒', '啤酒', '调和酒', '其他洋酒', '其他传统酒', '其他酒', '食品饮料（非生鲜）电商',
        '食品饮料（非生鲜）线下零售', '生鲜电商', '生鲜线下零售',
        '茶叶', '原叶茶', '袋泡茶', '代用', '花草', '再加工茶', '其他茶叶', '膳食营养品', '蛋白粉',
        '氨基酸', '胶原蛋白', '菌菇', '酵素',
        '运动营养食品', '膳食纤维', '功能糖果', '维生素', '矿物质', '钙铁锌硒', '其他膳食营养品',
        '传统滋补营养品', '燕窝', '枸杞', '枸杞制品', '蜂蜜',
        '蜂蜜制品', '阿胶膏方', '参类滋补品', '参茸贵细', '药食同源食品', '养生茶', '其他传统滋补营养品',
        '服装配饰', '其他服装配饰', '服装配饰电商',
        '服装配饰线下零售', '内衣裤袜', '内衣', '家居保暖衣', '袜', '鞋靴箱包', '箱包', '箱包配件',
        '男鞋', '女鞋', '运动鞋', '童鞋', '其他鞋类',
        '服饰', '女装', '男装', '童装', '服装加工定做', '特殊服饰', '腰带', '围巾', '帽', '手套',
        '其他服饰', '运动服', '服装配件', '配饰',
        '眼镜', '一般钟表', '珍珠宝石', '金银饰品', '小饰品', '其他配饰', '高档服装配饰', '医疗',
        '医疗机构', '美容整形', '口腔医院', '眼科医院',
        '高端妇幼', '男科医院', '妇科医院', '皮肤医院', '体检中心', '综合医院', '兽类医院', '诊所',
        '中医医院', '其他医疗机构', '中医馆', '植发机构',
        '康复医院', '医疗器械', '一类医疗器械', '二类医疗器械', '三类医疗器械', '其他医疗器械',
        '三类医疗器械-美瞳', '隐形眼镜', '药品', '补肾药', '妇科用药',
        '糖尿病药', '肝胆胰药', '呼吸系统药', '神经系统药', '泌尿系统药', '皮肤用药', '风湿关节药',
        '心脑血管药', '胃肠疾病药', '清热解毒药', '儿科药',
        '减肥药', '维生素和补充矿物质药', '其他药品', '中药饮片', '中草药', '保健品-国内', '促进排铅',
        '辅助降血压', '促进泌乳', '缓解体力疲劳',
        '对辐射危害有辅助保护作用', '促进生长发育', '改善营养性贫血', '调节肠道菌群', '通便',
        '对胃粘膜损伤有辅助保护功能', '祛黄褐斑', '改善皮肤油分', '辅助降血糖',
        '辅助降血脂', '清咽', '提高缺氧耐受力', '促进消化', '祛痤疮', '改善皮肤水分', '增加免疫力',
        '改善睡眠', '辅助改善记忆', '缓解视力疲劳', '减肥',
        '增加骨密度', '抗氧化', '化学性肝损伤辅助保护功能', '其他保健品', '医疗周边服务', '心理咨询',
        '视力矫正', '基因检测', '赴外医疗', '其他周边服务',
        '其他医疗', '医疗综合服务平台', '兽药', '网上药店/医药电商', '网上药店', '医药电商',
        '药店/医药线下零售', '药店', '医药线下零售', '保健品-跨境',
        '商务服务', '安全安保', '防盗报警', '保安安保', '警用装备', '门禁考勤', '交通消防',
        '其他安全安保', '视频监控', '包装印刷', '中介服务',
        '知识产权服务', '招标服务', '电商代入驻', '其他中介服务', '工商资质申请', '管理咨询',
        '业务咨询服务', '系统定制解决方案', '其他管理咨询服务', '广告服务',
        '会展服务', '家居展', '房产展会', '车展', '其他会展服务', '设计', '会计税务', '法律服务',
        '个人律师', '律所', '其他法律服务', '人力资源服务',
        '招聘服务', '劳务外包服务', '其他人力资源服务', '其他商务服务', '代运营服务', '跨境电商代运营',
        '短视频带货创业', '平台代运营', '其他代运营',
        '本土电商代运营', '生活服务', '生活服务综合平台', '便民服务', '开锁配钥', '洗衣护理', '搬家服务',
        '维修服务', '办证刻章', '丧葬服务', '宠物服务',
        '充值服务', '除虫服务', '洗浴', '汗蒸', '足疗', '按摩', '其他便民服务', '鉴定服务', '家政服务',
        '保洁', '保姆', '月嫂', '其他家政服务',
        '护养服务', '月子中心', '产后护理', '养老院', '其他护养服务', '婚纱摄影', '儿童摄影', '个性写真',
        '全家福', '证件照', '照片冲洗', '其他摄影',
        '孕产摄影', '美容美发', '美发', '美甲', '美容', 'SPA', '物理丰胸', '物理减肥', '其他美容美发',
        '眉型设计', '祛痘', '祛斑', '淡疤',
        '回收买卖', '奢侈品回收买卖', '酒水回收买卖', '药品回收买卖', '数码产品回收买卖', '综合回收买卖',
        '其他回收买卖', '租赁服务', '机械设备租赁',
        '办公设备租赁', '庆典会展租赁', '服装租赁', '家居租赁', '空调租赁', '户外装备租赁',
        '移动厕所租赁', '书籍租赁', '其他租赁服务', '婚恋服务', '配送服务',
        '移民服务', '情感咨询', '其他生活服务', '结婚服务', '婚礼策划', '婚纱及婚宴礼服', '其他结婚服务',
        '婚嫁平台', '房地产', '房地产开发商',
        '海外房地产开发商', '其他房地产开发商', '国内房地产开发商 - 纯商业', '国内房地产开发商 - 产业园',
        '国内房地产开发商 - 厂房', '国内房地产开发商 - 其他',
        '国内房地产开发商 - 商住', '房地产中介', '住房中介（公司）', '住房中介（个人）', '商业地产中介',
        '海外房地产中介', '其他房地产中介', '物业管理公司',
        '房地产销售代理', '其他房地产', '房地产综合服务平台', '房地产分销商', '家居建材', '家装主材',
        '门窗板材', '舒适系统', '其他家装主材', '陶瓷卫浴',
        '五金电工', '灯具照明', '其他家用五金电工', '锁具', '家具', '定制家具', '商用', '办公家具',
        '其他家具', '成品家具', '其他家居建材', '家居百货',
        '家装辅材', '装修环境治理', '其他家装辅材', '涂料胶纸', '家居建材线下零售', '家饰', '家纺',
        '装修设计及工程服务', '装修装饰设计', '防水补漏',
        '其他装修设计及工程服务', '家装平台', '教育培训', '幼儿教育', '幼儿园', '其他幼儿教育',
        '幼儿素质教育', '幼儿学科教育', '中小学教育', '其他中小学教育',
        '中小学素质教育', '中小学学校', '中小学学科教育', '学历教育', 'MBA', 'EMBA', '研究生',
        '其他学历教育', '本专科教育', '语言及留学',
        '成人英语培训', '汉语培训', '小语种培训', '其他语言培训', '留学服务', '兴趣培训', '音乐乐器',
        '书法美术', '舞蹈', '体育', '其他兴趣培训',
        '播音主持', '戏剧与写作', '智力培训', '职业技能', '厨师餐饮', 'IT技能培训', '其他职业技能',
        '汽车驾驶', '影像设计技能', '企业管理培训',
        '管理经营培训', '拓展培训', '其他企业管理培训', '特殊人群教育', '职业资格考证培训', '公务员',
        '医疗健康考试培训', '消防建筑', '金融财会',
        '其他职业资格考证培训', '心理类', '法律资格类', '教师类', '其他教育培训', '新媒体运营培训',
        '网络营销技能', '其他新媒体运营培训', '理财培训', '出行旅游',
        '景点', '旅游景点', '酒店住宿', '酒店宾馆', '民宿客栈', '商务会议', '其他酒店住宿',
        'OTA（online travel Agent）', '旅行社',
        '本地周边游', '国内线路游', '境外游', '会议旅游', '签证服务', '综合旅游', '其他旅行社',
        '航空公司', '公路客运公司', '邮轮', '商旅票务代理',
        '城市出行', '汽车租赁', '打车', '专车', '接机', '自行车', '非机动车租赁', '其他城市出行',
        '公共交通票务', '其他出行旅游', '外旅局', '社会公共',
        '政府政务文化旅游', '社会组织', '宗教', '宗教机构', '其他社会公共', '政府政务科教卫生',
        '政府政务环境安全', '游戏', '休闲游戏', '消除', '解谜',
        '其他休闲游戏', '棋牌桌游', '棋牌捕鱼桌游', '其他桌游', '角色扮演', '体育竞技', 'MOBA',
        '其他游戏', '射击游戏', '动作游戏', 'SLG',
        '塔防游戏', '模拟经营', '卡牌游戏', '音乐游戏', '游戏平台', '零售', '综合类2B电商',
        '垂直类2B电商', '综合类2C电商', '跨境类2C电商',
        '综合类线下零售', '商场', '购物中心', '综合超市', '便利店', '其他综合类线下零售', '其他零售',
        '交通工具', '飞机厂商', '船舶厂商', '摩托车厂商',
        '非机动车厂商', '自行车厂商', '电动车厂商', '其他非机动车厂商', '功能性车辆厂商', '其他交通工具',
        '交通工具后市场', '汽车', '汽车厂商', '小型车',
        'SUV', '厢型车', '跑车', '大中型客车', '其他汽车厂商', '汽车经销商', '二手车线下零售',
        '汽车后市场', '汽车清洁', '汽车零配件', '汽车配饰',
        '汽车保养维修', '汽车改装', '其他车后市场', '其他汽车', '汽车综合服务平台', '新车线下零售',
        '农林牧畜渔', '农业', '林业', '渔业', '畜牧业',
        '农林服务', '农产品加工', '化肥及农药', '其他农林牧畜渔', '化工及能源', '化工制品', '危险化学品',
        '食品化工材料', '化工其它', '燃料能源', '电力能源',
        '新能源', '矿产资源', '污染处理', '环保厕所', '垃圾处理', '水污染处理', '土壤污染处理',
        '空气污染处理', '噪音污染处理', '消毒灭菌', '环境评测',
        '其他污染处理', '废旧回收', '机械电子设备回收', '化工废料回收', '建筑废料回收', '塑料橡胶回收',
        '金属资源回收', '纸品回收', '纺织品与皮革回收',
        '综合废旧回收', '其他废旧回收', '节能', '其他化工及能源', '电子电工', '电子器件', '仪器仪表',
        '电工电气', '电工机械', '其他电子电工', '机械设备',
        '通用机械设备', '农林机械', '矿产机械', '建筑工程机械', '化工机械', '木材石材加工机械',
        '机床机械', '商用设备', '基础机械', '工具配件', '食品机械',
        '清洁通风设备', '其他机械设备', '机械设备线下零售', '文体娱乐', '演出票务及周边', '演唱会',
        '音乐会', '话剧戏曲相声', '歌舞剧', '杂技马戏木偶',
        '演出周边', '电影节', '其他演出票务及周边', '文化艺术收藏品', '邮票', '纪念章', '字画',
        '刀剑工艺品', '文物鉴定', '其他文玩杂项', '紫砂', '陶瓷',
        '钱币', '文具玩具礼品', '玩具', '桌游及动漫周边', '鲜花', '文具', '其他文具玩具礼品', '乐器',
        '民族乐器', '西洋乐器', '民族西洋乐器', '其他乐器',
        '室内娱乐', '桌游棋牌类', '密室逃脱', 'KTV', 'CLUB', 'DIY及体验馆', '电影院', '电子游艺厅',
        '室内儿童游乐', '轰趴馆', '网吧',
        '真人对抗游戏', '其他室内娱乐', '运动健身', '体育用品', '户外用品', '体育赛事及场馆',
        '体育赛事及周边', '体育场馆', '其他体育赛事及场馆', '彩票',
        '彩票资讯', '彩票售卖', '其他彩票', '户外娱乐', '其他文体娱乐', '文体娱乐电商',
        '文体娱乐线下零售', '传媒及内容', '出版传媒', '电视台', '广播台',
        '影视音像制作', '书籍杂志', '教辅', '教材类书籍杂志', '其他书籍杂志', '网络视听', '长视频',
        '短视频', '直播', '音频', '其他网络视听',
        '其他传媒及内容', '书籍杂志-实体书', '教材类实体书', '其他书籍杂志-实体书', '资讯',
        '一般会员卡券', '青年黑卡', '其他会员卡券', '新闻资讯', '综合资讯',
        '文化体育资讯', '旅游资讯', '房产资讯', '电商导购平台', '汽车资讯', '动漫资讯', '摄影资讯',
        '3C及家电资讯', '家居装修资讯', '美容服饰资讯',
        '母婴儿童资讯', '食品烹饪资讯', '宠物资讯', '医疗资讯', '其他资讯', '物流业', '快递物流',
        '普通快递运输', '货运代理', '特殊运输', '物流基础设施',
        '其他物流业', '通信', '电信运营商', '号卡', '流量包', '宽带', '彩铃', '虚拟运营商', '通信设备',
        '其他通信', '金融业', '银行业', '信用卡',
        '贷款', '银行理财', '银行服务', '其他银行业', '证券业', '股票及其衍生品交易',
        '债券及其衍生品交易', '其他证券业', '港股证券公司及证券投资',
        '美股证券公司及证券投资', '投资咨询', '顾问', '股权及其衍生品交易', '保险业', '保险经代公司',
        '保险公估业务', '其他保险业', '保险公司', '信托业',
        '担保及保理', '拍卖典当', '期货', '基金', '公募基金', '私募基金', '风险投资基金', '其他基金',
        '基金代销平台', 'FOF及MOM投资', '征信机构',
        '其他金融业', '银行卡组织', '综合理财', '理财超市', '综合投资', '其他综合理财', '贷款服务',
        '地方小额贷款公司', '互联网小贷', '消费金融', '融资租赁',
        '助贷服务', '其他信贷业', '外汇', '外汇现货', '贵金属', '境外贵金属现货交易', '贵金属交易所',
        '上海黄金交易所及其会员', '其他贵金属交易', 'P2P',
        'P2P贷款', 'P2P理财', '其他P2P', '第三方支付', 'POS机推广', '众筹', '数字货币', '金融门户网站',
        '综合金融平台及工具', '餐饮服务', '餐厅',
        '中式料理', '面包甜点', '其他餐厅', '西式料理', '日韩料理', '东南亚菜系', '饮品', '酒吧', '冷饮',
        '其他饮品', '其他餐饮服务', '工具类软件',
        '软件工具', '财务软件', '办公软件', '数据库软件', '制图软件', '开发软件', '其他软件工具',
        '多媒体处理', '图片拍摄及处理', '视频拍摄及处理',
        '音频录制及处理', '其他多媒体处理', '社交通讯', '一般社交通讯', '特殊社交通讯', '其他社交通讯',
        '实用工具', '浏览器', '杀毒软件', '性能优化',
        '地图导航', '日历闹钟', '天气服务', '词典翻译', '星座运势', '应用管理', '违章查询', '存储备份',
        '图文识别', '监控遥控', '效率软件', '测量绘图',
        '虚拟网络', '远程会议', '打印传输', '安全服务', '其他实用工具', '健康娱乐生活', '来电秀',
        '输入法', 'wifi', '桌面壁纸', '其他工具类软件',
        '招商加盟', '招商加盟联展平台', '生活用品加盟', '生活服务加盟', '服装配饰加盟', '美容美发加盟',
        '室内娱乐加盟', '教育培训加盟', '酒店加盟', '餐食加盟',
        '中式美食火锅类加盟', '中式美食面食类加盟', '中式美食烧烤类加盟', '中式美食风味小吃加盟',
        '中式美食其他加盟', '日韩美食加盟', '西式美食加盟', '其他美食加盟',
        '医疗医药加盟', '房产家居建材加盟', '家装建材加盟', '家居加盟', '建材零售加盟', '房产加盟',
        '五金电工加盟', '装修环境治理加盟', '其他建材加盟', '食品加盟',
        '工业加盟', '汽车产品加盟', '互联网软件加盟', '招聘中介加盟', '其他招商加盟', '减肥加盟',
        '饮品烘焙加盟', '保健品加盟', '酒加盟', '农业加盟',
        '商务服务加盟', '美妆', '一般化妆品', '保养护肤', '彩妆', '香水', '其他一般化妆品', '高档化妆品',
        '高档护肤品', '高档彩妆', '高档香水',
        '其他高档化妆品', '特殊化妆品', '育发', '染发', '烫发', '脱毛', '健美', '美乳', '祛斑美白',
        '除臭', '防晒', '其他特殊化妆品', '防脱发',
        '美妆工具', '化妆品线下零售', '化妆品电商', '母婴宠物', '宠物用品', '宠物食品', '宠物日用品',
        '其他宠物用品', '母婴用品电商', '母婴用品线下零售',
        '宠物用品电商', '宠物用品线下零售', '母婴服装', '孕妇用品', '儿童玩具', '母婴食品', '奶粉',
        '辅食', '营养品', '零食', '孕妇营养品', '其他母婴宠物',
        '婴童用品', '成人用品', '计生用品', '情趣用品', '其他成人用品', '日化', '特殊日化用品',
        '日化用品线下零售', '个人护理', '口腔护理', '身体洗护',
        '美发护发', '个护工具', '旅行用品', '卫生用品', '其他个人护理', '家庭护理品', '清洁剂', '家私',
        '皮具护理品', '驱虫用品', '室内除臭', '芳香用品',
        '其他家庭护理品', '其他日化用品', '日化用品电商', '股市基金', '金融财经', '理财', '保险', '会计',
        '银行', '融资', '网贷', '财务', '拍卖',
        '信托', '卡盟', '手游', 'APP', '页游', '小游戏', '电子竞技', '外挂', '泛娱乐', '影视',
        '娱乐八卦', '电影', '动漫', '旅游', '法律',
        '占卜算命', '起名', '古玩收藏', '收藏', '快递', '物流快递', '天气', '宠物', '政府', '佛教',
        '垂钓', '发型设计', '广场舞', '信息咨询',
        '基督教', '酒店', '吉他', '票务', '维修', '家电维修', '风水', '刑事律师', '奇闻异事', '广告',
        '租赁', '移民', '交友', '废品', '棋牌',
        '婚恋', '物业', '家政', '婚庆', '地震', '兽医', '博物馆', '爱恋挽回', '标牌标识', '清洁业',
        '宠物医院', '天文', '健康', '母婴',
        '整形美容', '女性', '整形', '妇科', '健身健美', '口腔牙科', '眼科', '两性', '中药', '瘦身',
        '不孕不育', '男科', '肿瘤', '儿科',
        '保健品', '生物科技', '痤疮', '月子', '足疗按摩', '生育', '性病', '招聘', '加盟', '招投标',
        '税务', '会展', '人力资源', '知识产权',
        '企业信息', '简历', '商标', '企业管理', '工商服务', '专利', '漫画', '音乐', '小说', '乐器演奏',
        '诗歌', '书法', '图书', '戏剧', '雕刻',
        '刺绣', '列车汽运', '二手车', '摩托', '卡车', '汽配', '轮胎', '装修', '房产', '租房', '建材',
        '全屋定制', '门窗', '锅炉', '灯具',
        '卫浴', '油漆', '水泥', '地板', '货架', '搬家', '窗帘', '教育', '散文作文', '高中', '职业培训',
        '小学', '考研', '驾校', '中学',
        '留学', '论文', '大学', '日语培训', '英语培训', '翻译', '在职研究生', '早教', '数学', '设计培训',
        'IT教育', '测绘', '绘画设计',
        'PC软件', '电商', '编程', '科技', '素材', 'QQ相关', 'U盘装机', '源码', '直播平台', '网站建设',
        '字体', '网络安全', '网络营销',
        '区块链', '比特币', '大数据', '域名主机', '电脑配件', '耗材', '网赚', '配音', '淘客', '小程序',
        '虚拟现实', '物联网', '数据恢复',
        '域名空间', '服装', '团购', '珠宝饰品', '手表', '化妆', '礼品工艺品', '微商', '笔记本', '鞋类',
        '奢侈品', '皮革', '床上用品', '美食',
        '菜谱', '酒类', '红酒', '餐饮', '餐饮加盟', '西餐', '厨房', '刀具', '火锅', '电子', '农业机械',
        '采暖设备', '音响器材', '电子元器件',
        '工控', '安防', '医疗设备', '五金', '包装', '土木工程', '照明电气', '机床', '硬件', '船舶',
        '投影', '保温材料', '纺织', '清洁设备',
        '加工中心', '餐饮设备', '齿轮', '勘探测绘', '检测', '空气净化器', '无人机', '空调', '军事',
        '航空航天', '海关', '养殖', '畜牧', '花卉',
        '水产', '园林景观', '木业', '木工', '园艺', '化工', '玻璃', '光伏', '能源', '塑料', '饲料',
        '农药', '铝业', '石材', '环保',
        '有色金属', '煤炭', '涂料', '纸业', '化肥', '天然气', '喷涂', '烟花', '石墨', '足球', '篮球',
        '武术', '太极拳', '户外', '高尔夫球',
        '瑜伽', '跑步', '游泳', '乒乓球']
